summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoPicture.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficecore/KoPicture.h')
-rw-r--r--lib/kofficecore/KoPicture.h70
1 files changed, 35 insertions, 35 deletions
diff --git a/lib/kofficecore/KoPicture.h b/lib/kofficecore/KoPicture.h
index e4ed1d5d..3fa355f8 100644
--- a/lib/kofficecore/KoPicture.h
+++ b/lib/kofficecore/KoPicture.h
@@ -20,17 +20,17 @@
#ifndef __koPicture_h__
#define __koPicture_h__
-#include <qstring.h>
-#include <qiodevice.h>
-#include <qpixmap.h>
+#include <tqstring.h>
+#include <tqiodevice.h>
+#include <tqpixmap.h>
#include <koffice_export.h>
#include "KoPictureKey.h"
class KoXmlWriter;
-class QPainter;
-class QSize;
-class QDragObject;
+class TQPainter;
+class TQSize;
+class TQDragObject;
class KURL;
class KoPictureShared;
@@ -87,31 +87,31 @@ public:
*
* The parameters @p width, @p height define the desired size for the picture
*
* The other parameters are very similar to QPainter::drawPixmap :
* (@p x, @p y) define the position in the painter,
* (@p sx, @p sy) specify the top-left point in picture that is to be drawn. The default is (0, 0).
* (@p sw, @p sh) specify the size of the picture that is to be drawn. The default, (-1, -1), means all the way to the bottom
* right of the pixmap.
*
*/
- void draw(QPainter& painter, int x, int y, int width, int height, int sx = 0, int sy = 0,
+ void draw(TQPainter& painter, int x, int y, int width, int height, int sx = 0, int sy = 0,
int sw = -1, int sh = -1, bool fastMode = false);
/**
* Create a dragobject containing this picture.
* @param dragSource must be 0 when copying to the clipboard
* @param name name for the QDragObject
* @return 0L if the picture is null, or if a dragobject for it isn't implemented [yet]
*/
- QDragObject* dragObject( QWidget *dragSource = 0L, const char *name = 0L );
+ TQDragObject* dragObject( TQWidget *dragSource = 0L, const char *name = 0L );
- bool load(QIODevice* io, const QString& extension);
+ bool load(TQIODevice* io, const TQString& extension);
/**
* Save picture into a QIODevice
* @param io QIODevice used for saving
*/
- bool save(QIODevice* io) const;
+ bool save(TQIODevice* io) const;
/**
* OASIS FlatXML support:
@@ -128,24 +128,24 @@ public:
/**
* @return the image extension (e.g. png)
*/
- QString getExtension(void) const;
+ TQString getExtension(void) const;
/**
* @return the image MIME type
*/
- QString getMimeType(void) const;
+ TQString getMimeType(void) const;
/**
* @return the original image size
*/
- QSize getOriginalSize(void) const;
+ TQSize getOriginalSize(void) const;
/**
* Clear and set the mode of this KoPicture
*
* @param newMode a file extension (like "png") giving the wanted mode
*/
- void clearAndSetMode(const QString& newMode);
+ void clearAndSetMode(const TQString& newMode);
/**
* Reset the KoPicture (but not the key!)
@@ -155,43 +155,43 @@ public:
/**
* Load the picture from a file named @p fileName
*/
- bool loadFromFile(const QString& fileName);
+ bool loadFromFile(const TQString& fileName);
/**
* Load the picture from base64-encoded data
*/
- bool loadFromBase64(const QCString& str);
+ bool loadFromBase64(const TQCString& str);
/**
* Load a potentially broken XPM file (for old files of KPresenter)
*/
- bool loadXpm(QIODevice* io);
+ bool loadXpm(TQIODevice* io);
/**
* @deprecated To be replaced by @ref KoPicture::draw
*
* Returns a QPixmap from an image
* Returns an empty QPixmap if the KoPicture is not an image.
*/
- QPixmap generatePixmap(const QSize& size, bool smoothScale = false);
+ TQPixmap generatePixmap(const TQSize& size, bool smoothScale = false);
/**
* Download and set the key for a possibly remote file.
*
* @param url the url to download from
- * @param window the parent widget for the download. You can pass
- * NULL (0) if you absolutely cannot find a parent
+ * @param window the tqparent widget for the download. You can pass
+ * NULL (0) if you absolutely cannot find a tqparent
* widget to use.
*/
- bool setKeyAndDownloadPicture(const KURL& url, QWidget *window);
+ bool setKeyAndDownloadPicture(const KURL& url, TQWidget *window);
/**
- * Generate a QImage
+ * Generate a TQImage
* (always in slow mode)
*
* @param size the wanted size for the QImage
*/
- QImage generateImage(const QSize& size);
+ TQImage generateImage(const TQSize& size);
/**
* @return TRUE if the alpha channel processing has been enabled
@@ -204,12 +204,12 @@ public:
void setAlphaBuffer(bool enable);
/**
- * Creates an alpha mask for the picture
+ * Creates an alpha tqmask for the picture
* (first you have to call @ref #setAlphaBuffer).
*
* @see hasAlphaBuffer() setAlphaBuffer()
*/
- QImage createAlphaMask(int conversion_flags = 0) const;
+ TQImage createAlphaMask(int conversion_flags = 0) const;
/**
* @brief Clear any cache
@@ -219,7 +219,7 @@ public:
*/
void clearCache(void);
- QString uniquePictureId() const;
+ TQString uniquePictureId() const;
void assignPictureId( uint _id);
protected:
@@ -238,7 +238,7 @@ protected:
* Creare the shared data if needed
*/
void createSharedData(void);
- QString uniqueName() const;
+ TQString uniqueName() const;
protected:
/**
@@ -253,7 +253,7 @@ protected:
KoPictureShared* m_sharedData;
static uint uniqueValue;
- QString m_uniqueName;
+ TQString m_uniqueName;
};
#endif /* __koPicture_h__ */
@@ -87,31 +87,31 @@ public:
* The parameters @p width, @p height define the desired size for the picture
*
- * The other parameters are very similar to QPainter::drawPixmap :
+ * The other parameters are very similar to TQPainter::drawPixmap :
* (@p x, @p y) define the position in the painter,
* (@p sx, @p sy) specify the top-left point in picture that is to be drawn. The default is (0, 0).
@@ -87,31 +87,31 @@ public:
* Create a dragobject containing this picture.
* @param dragSource must be 0 when copying to the clipboard
- * @param name name for the QDragObject
+ * @param name name for the TQDragObject
* @return 0L if the picture is null, or if a dragobject for it isn't implemented [yet]
*/
@@ -87,31 +87,31 @@ public:
/**
- * Save picture into a QIODevice
- * @param io QIODevice used for saving
+ * Save picture into a TQIODevice
+ * @param io TQIODevice used for saving
*/
@@ -155,43 +155,43 @@ public:
* @deprecated To be replaced by @ref KoPicture::draw
*
- * Returns a QPixmap from an image
- * Returns an empty QPixmap if the KoPicture is not an image.
+ * Returns a TQPixmap from an image
+ * Returns an empty TQPixmap if the KoPicture is not an image.
*/
@@ -155,43 +155,43 @@ public:
* (always in slow mode)
*
- * @param size the wanted size for the QImage
+ * @param size the wanted size for the TQImage
*/